package io.gisbi.application.module.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import io.gisbi.application.module.domain.Module;
import io.gisbi.application.module.mapper.ModuleMapper;
import io.gisbi.application.module.service.IModuleService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import io.gisbi.engine.utils.DateUtils;
import io.gisbi.utils.AuthUtils;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 应用_系统模块 服务实现类
 * </p>
 *
 * @author zhengsl
 * @since 2025-03-25
 */
@Service
public class ModuleServiceImpl extends ServiceImpl<ModuleMapper, Module> implements IModuleService {
    
    // 新增existsChildrenByPid实现
    @Override
    public boolean existsChildrenByPid(String  appId,String pid) {
        return this.count(new LambdaQueryWrapper<Module>()
                .eq(Module::getAppId, appId).eq(Module::getPid, pid)) > 0;
    }

    @Override
    public boolean initAppModules(String appId) {
        // 01:登录页面  02:主框架页面  03:GIS大屏页面  04:二级弹窗页面  05:数据填报页面   06:文档资源页面 09:自定义页面
        List<Module> list=new ArrayList<>();
        list.add(createInitModule(appId,"登录页面","01",1));
        list.add(createInitModule(appId,"主框架页面","02",2));
        list.add(createInitModule(appId,"GIS大屏页面","03",3));
        list.add(createInitModule(appId,"二级弹窗页面","04",4));
        list.add(createInitModule(appId,"数据填报页面","05",5));
        list.add(createInitModule(appId,"文档资源页面","06",6));
        list.add(createInitModule(appId,"自定义页面","09",9));
        boolean isok=this.saveBatch(list);
        return isok;
    }



    private Module createInitModule(String appId,String name,String type,Integer sort){
        Module initModule=new Module(
                appId,
                name,
                "00",
                1,
                "01",
                type,
                0,
                sort,
                LocalDateTime.now(),
                AuthUtils.getUser().getUserId().toString()
        );
        return initModule;
    }

    @Override
    public boolean deleteAppModules(String appId) {
        if(this.remove(new LambdaQueryWrapper<Module>().eq(Module::getAppId,appId))){
            return true;
        }
        return false;
    }
}